Module: MetaPresenter
- Defined in:
- lib/meta_presenter.rb,
lib/meta_presenter/base.rb,
lib/meta_presenter/builder.rb,
lib/meta_presenter/helpers.rb,
lib/meta_presenter/base/delegate_all_to.rb,
lib/meta_presenter/base/delegate_to_controller.rb
Overview
MetaPresenter is a Ruby gem that gives you access to the
powerful presenter pattern in your Rails controllers. For each
controller/action pair you get a presenter class in app/presenters
that you can use in your views with with presenter.method_name.
This helps you decompose your helper logic into tight, easily
testable classes. There's even a DSL for method delegation
on objects to reduce boilerplate.